TrainingLoop
============

.. currentmodule:: pykeen.training

.. autoclass:: TrainingLoop
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~TrainingLoop.checksum
      ~TrainingLoop.device
      ~TrainingLoop.hpo_default
      ~TrainingLoop.loss

   .. rubric:: Methods Summary

   .. autosummary::

      ~TrainingLoop.batch_size_search
      ~TrainingLoop.get_normalized_name
      ~TrainingLoop.sub_batch_and_slice
      ~TrainingLoop.train

   .. rubric:: Attributes Documentation

   .. autoattribute:: checksum
   .. autoattribute:: device
   .. autoattribute:: hpo_default
   .. autoattribute:: loss

   .. rubric:: Methods Documentation

   .. automethod:: batch_size_search
   .. automethod:: get_normalized_name
   .. automethod:: sub_batch_and_slice
   .. automethod:: train
